==> sveltekit-adapter-firebase-0.0.5.tgz: package/src/lib/adapter.js <==
import { __awaiter } from "tslib";
import { readFileSync, writeFileSync } from 'fs';
import { join } from 'path';
import { fileURLToPath } from 'url';
const distPath = fileURLToPath(new URL('.', import.meta.url).href);
export default function (options) {
    return {
        name: '@outcom/adapter-firebase',
        adapt(builder) {
            return __awaiter(this, void 0, void 0, function* () {
                const { outDir, v2, functionOptions, functionName, nodeVersion } = options || {
                    outDir: 'build',
                    v2: true,
                    functionOptions: { concurrency: 500 },
                    functionName: 'handler',
                    nodeVersion: '16'
                };
                // empty out existing build directories
                builder.rimraf(outDir);
                builder.rimraf('.firebase');
                builder.log.minor(`Publishing to "${outDir}"`);
                builder.log.minor('Copying assets...');
                const publishDir = `${outDir}${builder.config.kit.paths.base}`;
                builder.writeClient(publishDir);
                builder.writePrerendered(publishDir);
                if (!v2 && functionOptions) {
                    throw new Error('Function options can only be used with v2 functions');
                }
                yield generateCloudFunction(builder, outDir, v2, nodeVersion, functionName, functionOptions);
                builder.log.info('Generating production package.json for Firebase...');
                generateProductionPackageJson(outDir, nodeVersion);
            });
        },
    };
}
function generateCloudFunction(builder, publish, v2, nodeVersion, functionName, functionOptions) {
    return __awaiter(this, void 0, void 0, function* () {
        builder.mkdirp(join(publish, '.firebase', 'functions'));
        builder.writeServer(join(publish, '.firebase', 'server'));
        const replace = {
            '0SERVER': './server/index.js', // digit prefix prevents CJS build from using this as a variable name, which would also get replaced
        };
        const filter = (name) => {
            if (name === 'lib') {
                return true;
            }
            return !name.includes('adapter') && name.endsWith('.js');
        };
        builder.copy(`${distPath}`, join(publish, '.firebase'), { filter, replace });
        builder.log.minor('Generating cloud function...');
        const manifest = builder.generateManifest({
            relativePath: '../server',
            format: 'esm',
        });
        const initImport = `import { init } from './../function.js';`;
        const firebaseImportV2 = `import { onRequest } from 'firebase-functions/v2/https';`;
        const functionConstV2 = `export const ${functionName} = onRequest(${functionOptions ? JSON.stringify(functionOptions) + ', ' : ''}init(${manifest}, ${v2}));`;
        const firebaseImportV1 = `import { https } from 'firebase-functions';`;
        const functionConstV1 = `export const ${functionName} = https.onRequest(init(${manifest}));`;
        const renderFunctionFile = `${initImport}\n${v2 ? firebaseImportV2 : firebaseImportV1}\n\n${v2 ? functionConstV2 : functionConstV1}\n`;
        writeFileSync(join(publish, '.firebase', 'functions', 'render.js'), renderFunctionFile);
    });
}
function generateProductionPackageJson(outDir, nodeVersion) {
    const packageJsonString = readFileSync('package.json');
    const packageJson = JSON.parse(packageJsonString.toString());
    const firebaseConfig = {
        dependencies: Object.assign(Object.assign({}, packageJson.dependencies), { 'firebase-functions': '^3.24.1', '@sveltejs/kit': 'next' }),
        main: '.firebase/functions/render.js',
        engines: {
            node: nodeVersion,
        },
        type: 'module',
    };
    const updatedPackageJson = Object.assign(Object.assign({}, packageJson), firebaseConfig);
    writeFileSync(join(outDir, 'package.json'), JSON.stringify(updatedPackageJson, null, 2));
}

==> sveltekit-adapter-firebase-0.0.6.tgz: package/src/lib/adapter.js <==
import { __awaiter } from "tslib";
import { readFileSync, writeFileSync } from 'fs';
import { join } from 'path';
import { fileURLToPath } from 'url';
const distPath = fileURLToPath(new URL('.', import.meta.url).href);
export default function (options) {
    return {
        name: '@outcom/adapter-firebase',
        adapt(builder) {
            return __awaiter(this, void 0, void 0, function* () {
                const { outDir, v2, functionOptions, functionName, nodeVersion, } = options || {
                    outDir: 'build',
                    v2: true,
                    functionOptions: { concurrency: 500 },
                    functionName: 'handler',
                    nodeVersion: '16',
                };
                // empty out existing build directories
                builder.rimraf(outDir);
                builder.rimraf('.firebase');
                builder.log.minor(`Publishing to "${outDir}"`);
                builder.log.minor('Copying assets...');
                const publishDir = `${outDir}${builder.config.kit.paths.base}`;
                builder.writeClient(publishDir);
                builder.writePrerendered(publishDir);
                if (!v2 && functionOptions) {
                    throw new Error('Function options can only be used with v2 functions');
                }
                yield generateCloudFunction(builder, outDir, v2, nodeVersion, functionName, functionOptions);
                builder.log.info('Generating production package.json for Firebase...');
                generateProductionPackageJson(outDir, nodeVersion);
            });
        },
    };
}
function generateCloudFunction(builder, publish, v2, nodeVersion, functionName, functionOptions) {
    return __awaiter(this, void 0, void 0, function* () {
        builder.mkdirp(join(publish, '.firebase', 'functions'));
        builder.writeServer(join(publish, '.firebase', 'server'));
        const replace = {
            '0SERVER': './server/index.js', // digit prefix prevents CJS build from using this as a variable name, which would also get replaced
        };
        const filter = (name) => {
            if (name === 'lib') {
                return true;
            }
            return !name.includes('adapter') && name.endsWith('.js');
        };
        builder.copy(`${distPath}`, join(publish, '.firebase'), { filter, replace });
        builder.log.minor('Generating cloud function...');
        const manifest = builder.generateManifest({
            relativePath: '../server',
            format: 'esm',
        });
        const initImport = `import { init } from './../function.js';`;
        const firebaseImportV2 = `import { onRequest } from 'firebase-functions/v2/https';`;
        const functionConstV2 = `export const ${functionName} = onRequest(${functionOptions ? JSON.stringify(functionOptions) + ', ' : ''}init(${manifest}, ${v2}));`;
        const firebaseImportV1 = `import { https } from 'firebase-functions';`;
        const functionConstV1 = `export const ${functionName} = https.onRequest(init(${manifest}));`;
        const renderFunctionFile = `${initImport}\n${v2 ? firebaseImportV2 : firebaseImportV1}\n\n${v2 ? functionConstV2 : functionConstV1}\n`;
        writeFileSync(join(publish, '.firebase', 'functions', 'render.js'), renderFunctionFile);
    });
}
function generateProductionPackageJson(outDir, nodeVersion) {
    const packageJsonString = readFileSync('package.json');
    const packageJson = JSON.parse(packageJsonString.toString());
    const firebaseConfig = {
        dependencies: Object.assign(Object.assign({}, packageJson.dependencies), { 'firebase-functions': '^3.24.1', '@sveltejs/kit': 'next' }),
        main: '.firebase/functions/render.js',
        engines: {
            node: nodeVersion,
        },
        type: 'module',
    };
    const updatedPackageJson = Object.assign(Object.assign({}, packageJson), firebaseConfig);
    writeFileSync(join(outDir, 'package.json'), JSON.stringify(updatedPackageJson, null, 2));
}
